# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: login_response.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14login_response.proto\"\x85\x01\n\rLoginResponse\x12\x14\n\x0clogin_status\x18\x01 \x01(\x05\x12\x13\n\x0bprivate_key\x18\x02 \x01(\x0c\x12\x12\n\npublic_key\x18\x03 \x01(\x0c\x12\r\n\x05\x61\x64min\x18\x04 \x01(\x08\x12\x15\n\rserial_number\x18\x05 \x01(\t\x12\x0f\n\x07user_id\x18\x06 \x01(\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'login_response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LOGINRESPONSE']._serialized_start=25
  _globals['_LOGINRESPONSE']._serialized_end=158
# @@protoc_insertion_point(module_scope)
