# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: call_events_request.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x63\x61ll_events_request.proto\"\x83\x01\n\tCallEvent\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\x03\x12\x14\n\x0c\x65vent_number\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\t\x12\x10\n\x08platform\x18\x05 \x01(\x05\x12\x0c\n\x04user\x18\x06 \x01(\x03\x12\x12\n\ninserttime\x18\x07 \x01(\x03\"/\n\x11\x43\x61llEventsRequest\x12\x1a\n\x06\x65vents\x18\x01 \x03(\x0b\x32\n.CallEvent')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'call_events_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CALLEVENT']._serialized_start=30
  _globals['_CALLEVENT']._serialized_end=161
  _globals['_CALLEVENTSREQUEST']._serialized_start=163
  _globals['_CALLEVENTSREQUEST']._serialized_end=210
# @@protoc_insertion_point(module_scope)
