"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LoginResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOGIN_STATUS_FIELD_NUMBER: builtins.int
    PRIVATE_KEY_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    ADMIN_FIELD_NUMBER: builtins.int
    SERIAL_NUMBER_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    login_status: builtins.int
    private_key: builtins.bytes
    public_key: builtins.bytes
    admin: builtins.bool
    serial_number: builtins.str
    user_id: builtins.int
    def __init__(
        self,
        *,
        login_status: builtins.int | None = ...,
        private_key: builtins.bytes | None = ...,
        public_key: builtins.bytes | None = ...,
        admin: builtins.bool | None = ...,
        serial_number: builtins.str | None = ...,
        user_id: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["admin", b"admin", "login_status", b"login_status", "private_key", b"private_key", "public_key", b"public_key", "serial_number", b"serial_number", "user_id", b"user_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["admin", b"admin", "login_status", b"login_status", "private_key", b"private_key", "public_key", b"public_key", "serial_number", b"serial_number", "user_id", b"user_id"]) -> None: ...

global___LoginResponse = LoginResponse
