# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: devices_list_response.proto
# Protobuf Python Version: 4.25.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x64\x65vices_list_response.proto\"\x9d\x01\n\x06\x44\x65vice\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0c\n\x04icon\x18\x04 \x01(\x05\x12\x12\n\ninserttime\x18\x05 \x01(\x03\x12\x11\n\tfavourite\x18\x06 \x01(\x08\x12\x1a\n\x12\x61ssigned_place_ids\x18\x07 \x03(\x03\x12\x1a\n\x12\x61ssigned_group_ids\x18\x08 \x03(\x03\"/\n\x13\x44\x65vicesListResponse\x12\x18\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x07.Device')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'devices_list_response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DEVICE']._serialized_start=32
  _globals['_DEVICE']._serialized_end=189
  _globals['_DEVICESLISTRESPONSE']._serialized_start=191
  _globals['_DEVICESLISTRESPONSE']._serialized_end=238
# @@protoc_insertion_point(module_scope)
